#!/bin/bash

stat=$1
deep=$2
patt=$3
path=$4

# messages
usage="$0 status depth pattern depotpath"
nstat="Unknown status: $stat"
nonum="Non-numeric depth: $deep"
param="Unexpected parameters provided - need four."
npath="Ignoring path ($path) for status '$stat'"

if [ "$#" -eq 0 ]; then echo $usage; exit 0; fi

if ! [[ $deep =~ ^[0-9]+$ ]] ; then 
	echo $usage
	echo $nonum
	exit 2
fi

case "$stat" in 
	pending|shelved)
		echo $npath
		chgs=`p4 -F %change% -ztag changes -s $stat -m$deep`
	;;
	submitted)
		chgs=`p4 -F %change% -ztag changes -s $stat -m$deep $path`
	;;
	*)
		echo $usage
		echo $nstat
		exit 3
	;;
esac

if [ "$#" -ne 4 ]; then
	echo $usage
	echo $param
	exit 1
else
	echo "Searching the last $deep changes in '$path' for descriptions containing '$patt'"
fi

total=0
found=0

for c in $chgs; do
	testdesc=`p4 -F %Description% -ztag change -o $c | grep $patt`
	rc=$?; if [[ $rc == 0 ]]; then echo "Change: $c"; (( found++ )); fi 
	(( total++ ))
done
echo Searched $total, found $found
